@@ -52,21 +52,16 @@ package com.openexchange.subscribe.microformats.osgi;
 import org.osgi.framework.BundleActivator;
 import com.openexchange.server.osgiservice.CompositeBundleActivator;
 
-
 /**
  * {@link Activator}
- *
+ * 
  * @author <a href="mailto:francisco.laguna@open-xchange.com">Francisco Laguna</a>
- *
  */
 public class Activator extends CompositeBundleActivator {
 
-
-    private static final BundleActivator[] ACTIVATORS = new BundleActivator[] {new SubcriptionServicesActivator(), new ExternalSourcesActivator()};
-    
     @Override
     protected BundleActivator[] getActivators() {
-        return ACTIVATORS;
+        return new BundleActivator[] { new SubcriptionServicesActivator(), new ExternalSourcesActivator() };
     }
 
 }
